package org.xbib.event.clock;

import java.time.Instant;
import java.util.concurrent.Callable;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.xbib.event.bus.EventBus;

public class ClockEventService implements Callable<Integer> {

    private static final Logger logger = Logger.getLogger(ClockEventService.class.getName());

    private final ClockEventManagerService manager;

    private final EventBus eventBus;

    private final String name;

    private final Class<? extends ClockEvent> eventClass;

    public ClockEventService(ClockEventManagerService manager,
                             EventBus eventBus,
                             String name,
                             Class<? extends ClockEvent> eventClass) {
        this.manager = manager;
        this.eventBus = eventBus;
        this.name = name;
        this.eventClass = eventClass;
    }

    @Override
    public Integer call() {
        try {
            if (manager.getSuspended().contains(name)) {
                logger.log(Level.FINE, "clock event " + name + " suspended");
                return 1;
            } else {
                logger.log(Level.FINE, "posting clock event " + eventClass.getName());
                ClockEvent clockEvent = eventClass.getDeclaredConstructor().newInstance();
                clockEvent.setInstant(Instant.now());
                eventBus.post(clockEvent);
                return 0;
            }
        } catch (Throwable t) {
            logger.log(Level.WARNING, t.getMessage(), t);
            return 1;
        }
    }
}
