package org.xbib.event;

import org.junit.jupiter.api.Test;
import org.xbib.event.bus.Subscribe;
import org.xbib.event.common.EventManager;
import org.xbib.event.generic.GenericEventImpl;
import org.xbib.event.generic.GenericEvent;
import org.xbib.settings.Settings;

import java.util.concurrent.CompletableFuture;
import java.util.concurrent.ExecutionException;
import java.util.logging.Level;
import java.util.logging.Logger;

public class EventManagerTest {

    private static final Logger logger = Logger.getLogger(EventManagerTest.class.getName());

    @Test
    void testGenericEvents() {
        Settings settings = Settings.settingsBuilder()
                .build();
        TestEventConsumer consumer = new TestEventConsumer();
        EventManager eventManager = EventManager.builder(settings)
                .register(consumer)
                .build();
        eventManager.getGenericEventManagerService().post(new GenericEventImpl(e -> {
            logger.log(Level.INFO, "received event " + e);
        }));
    }


    @Test
    void testGenericEventWithWaitForSubscriber() throws InterruptedException, ExecutionException {
        Settings settings = Settings.settingsBuilder()
                .build();
        TestEventConsumer consumer = new TestEventConsumer();
        EventManager eventManager = EventManager.builder(settings)
                .register(consumer)
                .build();
        CompletableFuture<GenericEvent> future = new CompletableFuture<>();
        eventManager.getGenericEventManagerService().post(new GenericEventImpl(e -> {
            logger.log(Level.INFO, "received event " + e);
            future.complete(e);
        }));
        GenericEvent e = future.get();
        logger.log(Level.INFO, "the event was received with result " + e + ", continuing");
    }

    @Test
    void testGenericEventWithWaitForAllConsumers() throws ExecutionException, InterruptedException {
        Settings settings = Settings.settingsBuilder()
                .build();
        TestEventConsumer consumer1 = new TestEventConsumer();
        TestEventConsumer consumer2 = new TestEventConsumer();
        EventManager eventManager = EventManager.builder(settings)
                .register(consumer1)
                .register(consumer2)
                .loadEventConsumers()
                .build();
        CompletableFuture<GenericEvent> future = new CompletableFuture<>();
        eventManager.getGenericEventManagerService().post(new GenericEventImpl(e -> {
            logger.log(Level.INFO, "received event " + e);
        }), future);
        GenericEvent e = future.get();
        logger.log(Level.INFO, "the event " + e + " was received by all consumers, continuing");
    }

    private static class TestEventConsumer implements EventConsumer {

        TestEventConsumer() {
        }

        @Subscribe
        public void onEvent(GenericEventImpl event) {
            event.received();
        }
    }
}
