package org.xbib.event.path;

import org.junit.jupiter.api.Test;
import org.xbib.event.common.EventManager;
import org.xbib.settings.Settings;

import java.io.BufferedWriter;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.logging.Level;
import java.util.logging.Logger;

public class FileFollowEventManagerTest {

    private static final Logger logger = Logger.getLogger(FileFollowEventManagerTest.class.getName());

    @Test
    public void testFileFollowEvents() throws IOException, InterruptedException {
        Path path = Files.createTempDirectory("testfilefollow");
        TestFileFollowEventConsumer consumer = new TestFileFollowEventConsumer();
        Settings settings = Settings.settingsBuilder()
                .put("event.filefollow.testfilefollowevent.enabled", "true")
                .put("event.filefollow.testfilefollowevent.class", "org.xbib.event.io.file.TestFileFollowEvent")
                .put("event.filefollow.testfilefollowevent.base", path.toString())
                .put("event.filefollow.testfilefollowevent.pattern", ".*")
                .build();
        EventManager eventManager = EventManager.builder(settings)
                .register(consumer)
                .build();
        Thread.sleep(5000L);
        try (BufferedWriter bufferedWriter = Files.newBufferedWriter(path.resolve("test.txt"))) {
            bufferedWriter.write("Hello");
            logger.log(Level.INFO, "Hello written");
        }
        Thread.sleep(5000L);
        Files.delete(path.resolve("test.txt"));
        Files.delete(path);
        eventManager.close();
    }
}
