package org.xbib.event.net.http;

import org.xbib.event.common.EventManager;
import org.xbib.event.common.EventImpl;
import org.xbib.net.http.HttpHeaderNames;
import org.xbib.net.http.HttpHeaderValues;
import org.xbib.net.http.HttpMethod;
import org.xbib.net.http.server.service.BaseHttpService;
import org.xbib.net.http.server.service.HttpService;

import java.nio.charset.StandardCharsets;

import static org.xbib.net.http.HttpResponseStatus.NOT_FOUND;
import static org.xbib.net.http.HttpResponseStatus.OK;

public class EventReceiverService {

    private final EventManager eventManager;

    public EventReceiverService(EventManager eventManager) {
        this.eventManager = eventManager;
    }

    public HttpService createService(String prefix) {
        return BaseHttpService.builder()
                .setPrefix(prefix)
                .setPath("/event/{type}")
                .setMethod(HttpMethod.POST)
                .setHandler(ctx -> {
                    EventImpl event = EventImpl.fromJson(ctx.getRequest().asJson());
                    if (event.isNullEvent()) {
                        ctx.status(NOT_FOUND).done();
                    } else {
                        eventManager.submit(event);
                        ctx.status(OK)
                                .header(HttpHeaderNames.CONTENT_TYPE, HttpHeaderValues.APPLICATION_JSON)
                                .charset(StandardCharsets.UTF_8)
                                .body(event.toJson())
                                .done();
                    }
                })
                .build();
    }
}
