package org.xbib.event.syslog;

import java.net.InetAddress;
import java.time.LocalDateTime;

public class DefaultSyslogRequest implements SyslogRequest {

    private final Builder builder;

    private DefaultSyslogRequest(Builder builder) {
        this.builder = builder;
    }

    public static Builder builder() {
        return new Builder();
    }

    @Override
    public LocalDateTime receivedDate() {
        return builder.receivedDate;
    }

    @Override
    public InetAddress remoteAddress() {
        return builder.remoteAddress;
    }

    @Override
    public String rawMessage() {
        return builder.rawMessage;
    }

    public static class Builder implements SyslogRequest.Builder {

        LocalDateTime receivedDate;

        InetAddress remoteAddress;

        String rawMessage;

        private Builder() {
        }

        public Builder receivedDate(LocalDateTime receivedDate) {
            this.receivedDate = receivedDate;
            return this;
        }

        public Builder remoteAddress(InetAddress remoteAddress) {
            this.remoteAddress = remoteAddress;
            return this;
        }

        public Builder rawMessage(String rawMessage) {
            this.rawMessage = rawMessage;
            return this;
        }

        public SyslogRequest build() {
            return new DefaultSyslogRequest(this);
        }
    }
}
