package org.xbib.event.syslog;

import org.xbib.datastructures.api.Builder;
import org.xbib.event.Event;

import java.net.InetAddress;
import java.time.LocalDateTime;
import java.util.List;

/**
 * Represents a standard syslog message.
 */
public interface Message extends Event {
    /**
     * Date of the message. This is the parsed date from the client.
     *
     * @return date of the message
     */
    LocalDateTime date();

    /**
     * IP Address for the sender of the message.
     *
     * @return sender IP Address
     */
    InetAddress remoteAddress();

    /**
     * Unprocessed copy of the message.
     *
     * @return Unprocessed message
     */
    String rawMessage();

    MessageType type();

    /**
     * Level for the message. Parsed from the message.
     *
     * @return message Level
     */
    Integer level();

    /**
     * Version of the message.
     *
     * @return message version
     */
    Integer version();

    /**
     * Facility of the message.
     *
     * @return message facility
     */
    Integer facility();

    /**
     * Host of the message. This is the value from the message.
     *
     * @return message host
     */
    String host();

    /**
     * Message part of the overall syslog message.
     *
     * @return message part of the overall syslog message
     */
    String message();

    String processId();

    String tag();

    String messageId();

    String appName();

    List<Builder> structuredData();

    String deviceVendor();

    String deviceProduct();

    String deviceVersion();

    String deviceEventClassId();

    String name();

    String severity();

}
